@@ -11,7 +11,6 @@ from composer import utils
 
 HEADER = ['Task', 'Dataset', 'Name', 'Quality', 'Metric', 'TTT', 'Hparams']
 ATTRIBUTES = ['_task', '_dataset', '_name', '_quality', '_metric', '_ttt', '_hparams']
-GITHUB_BASE = 'https://github.com/mosaicml/mosaicml/tree/dev/composer/models/'  # TODO: update for launch
 
 folder_path = Path(__file__).parent
 models = utils.list_dirs(folder_path)
@@ -29,9 +28,9 @@ metadata = utils.get_metadata(
 
 # add extra keys
 for name, md in metadata.items():
-    md['_github_link'] = GITHUB_BASE + name
-    md['_hparams_path'] = os.path.join('composer', 'models', name, md['_hparams'])
-    md['_hparams_link'] = f"{GITHUB_BASE}/{name}/{md['_hparams']}"
+    md['_github_link'] = f"{name}/"
+    md['_hparams_path'] = os.path.join('composer', 'yamls', 'models', md['_hparams'])
+    md['_hparams_link'] = f"../yamls/models/{md['_hparams']}"
 
 # define row format
 row = [
@@ -41,7 +40,7 @@ row = [
     '{_quality}',
     '{_metric}',
     '{_ttt}',
-    '[{_hparams_path}]({_hparams})',
+    '[{_hparams_path}]({_hparams_link})',
 ]
 
 table_md = utils.build_markdown_table(
