@@ -9,4 +9,4 @@ _name = 'SimpleConvNet'
 _quality = ''
 _metric = 'Accuracy'
 _ttt = '?'
-_hparams = 'hparams_cpu.yaml'
+_hparams = 'classify_mnist_cpu.yaml'
